# -*- coding: utf-8 -*-


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_SettingsWindow(object):
    def setupUi(self, SettingsWindow):
        SettingsWindow.setObjectName("SettingsWindow")
        SettingsWindow.resize(752, 464)
        self.centralwidget = QtWidgets.QWidget(SettingsWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.tabWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.gridLayout = QtWidgets.QGridLayout(self.tab)
        self.gridLayout.setObjectName("gridLayout")
        self.label_6 = QtWidgets.QLabel(self.tab)
        self.label_6.setObjectName("label_6")
        self.gridLayout.addWidget(self.label_6, 0, 0, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(self.tab)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.label_2 = QtWidgets.QLabel(self.tab)
        self.label_2.setObjectName("label_2")
        self.verticalLayout.addWidget(self.label_2)
        self.label_3 = QtWidgets.QLabel(self.tab)
        self.label_3.setObjectName("label_3")
        self.verticalLayout.addWidget(self.label_3)
        self.label_4 = QtWidgets.QLabel(self.tab)
        self.label_4.setObjectName("label_4")
        self.verticalLayout.addWidget(self.label_4)
        self.label_5 = QtWidgets.QLabel(self.tab)
        self.label_5.setObjectName("label_5")
        self.verticalLayout.addWidget(self.label_5)
        self.horizontalLayout.addLayout(self.verticalLayout)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.def_GD = QtWidgets.QLineEdit(self.tab)
        self.def_GD.setMinimumSize(QtCore.QSize(0, 35))
        self.def_GD.setObjectName("def_GD")
        self.verticalLayout_2.addWidget(self.def_GD)
        self.def_GDD = QtWidgets.QLineEdit(self.tab)
        self.def_GDD.setMinimumSize(QtCore.QSize(0, 35))
        self.def_GDD.setObjectName("def_GDD")
        self.verticalLayout_2.addWidget(self.def_GDD)
        self.def_TOD = QtWidgets.QLineEdit(self.tab)
        self.def_TOD.setMinimumSize(QtCore.QSize(0, 35))
        self.def_TOD.setObjectName("def_TOD")
        self.verticalLayout_2.addWidget(self.def_TOD)
        self.def_FOD = QtWidgets.QLineEdit(self.tab)
        self.def_FOD.setMinimumSize(QtCore.QSize(0, 35))
        self.def_FOD.setObjectName("def_FOD")
        self.verticalLayout_2.addWidget(self.def_FOD)
        self.def_QOD = QtWidgets.QLineEdit(self.tab)
        self.def_QOD.setMinimumSize(QtCore.QSize(0, 35))
        self.def_QOD.setObjectName("def_QOD")
        self.verticalLayout_2.addWidget(self.def_QOD)
        self.horizontalLayout.addLayout(self.verticalLayout_2)
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.label_9 = QtWidgets.QLabel(self.tab)
        self.label_9.setObjectName("label_9")
        self.verticalLayout_7.addWidget(self.label_9)
        self.label_10 = QtWidgets.QLabel(self.tab)
        self.label_10.setObjectName("label_10")
        self.verticalLayout_7.addWidget(self.label_10)
        self.label_11 = QtWidgets.QLabel(self.tab)
        self.label_11.setObjectName("label_11")
        self.verticalLayout_7.addWidget(self.label_11)
        self.label_12 = QtWidgets.QLabel(self.tab)
        self.label_12.setObjectName("label_12")
        self.verticalLayout_7.addWidget(self.label_12)
        self.label_13 = QtWidgets.QLabel(self.tab)
        self.label_13.setObjectName("label_13")
        self.verticalLayout_7.addWidget(self.label_13)
        self.horizontalLayout.addLayout(self.verticalLayout_7)
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.def_GD_std = QtWidgets.QLineEdit(self.tab)
        self.def_GD_std.setMinimumSize(QtCore.QSize(0, 35))
        self.def_GD_std.setObjectName("def_GD_std")
        self.verticalLayout_6.addWidget(self.def_GD_std)
        self.def_GDD_std = QtWidgets.QLineEdit(self.tab)
        self.def_GDD_std.setMinimumSize(QtCore.QSize(0, 35))
        self.def_GDD_std.setObjectName("def_GDD_std")
        self.verticalLayout_6.addWidget(self.def_GDD_std)
        self.def_TOD_std = QtWidgets.QLineEdit(self.tab)
        self.def_TOD_std.setMinimumSize(QtCore.QSize(0, 35))
        self.def_TOD_std.setObjectName("def_TOD_std")
        self.verticalLayout_6.addWidget(self.def_TOD_std)
        self.def_FOD_std = QtWidgets.QLineEdit(self.tab)
        self.def_FOD_std.setMinimumSize(QtCore.QSize(0, 35))
        self.def_FOD_std.setObjectName("def_FOD_std")
        self.verticalLayout_6.addWidget(self.def_FOD_std)
        self.def_QOD_std = QtWidgets.QLineEdit(self.tab)
        self.def_QOD_std.setMinimumSize(QtCore.QSize(0, 35))
        self.def_QOD_std.setObjectName("def_QOD_std")
        self.verticalLayout_6.addWidget(self.def_QOD_std)
        self.horizontalLayout.addLayout(self.verticalLayout_6)
        self.gridLayout.addLayout(self.horizontalLayout, 0, 1, 1, 1)
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_8 = QtWidgets.QLabel(self.tab)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_3.addWidget(self.label_8)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem)
        self.label_7 = QtWidgets.QLabel(self.tab)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_3.addWidget(self.label_7)
        self.verticalLayout_5.addLayout(self.horizontalLayout_3)
        self.gridLayout.addLayout(self.verticalLayout_5, 1, 1, 1, 1)
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.tab_2)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem1)
        self.label_14 = QtWidgets.QLabel(self.tab_2)
        self.label_14.setObjectName("label_14")
        self.verticalLayout_8.addWidget(self.label_14)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem2)
        self.label_15 = QtWidgets.QLabel(self.tab_2)
        self.label_15.setObjectName("label_15")
        self.verticalLayout_8.addWidget(self.label_15)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem3)
        self.label_16 = QtWidgets.QLabel(self.tab_2)
        self.label_16.setObjectName("label_16")
        self.verticalLayout_8.addWidget(self.label_16)
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem4)
        self.horizontalLayout_4.addLayout(self.verticalLayout_8)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        spacerItem5 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem5)
        self.cff_extend = QtWidgets.QLineEdit(self.tab_2)
        self.cff_extend.setMinimumSize(QtCore.QSize(0, 35))
        self.cff_extend.setObjectName("cff_extend")
        self.verticalLayout_4.addWidget(self.cff_extend)
        spacerItem6 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem6)
        self.cff_threshold = QtWidgets.QLineEdit(self.tab_2)
        self.cff_threshold.setMinimumSize(QtCore.QSize(0, 35))
        self.cff_threshold.setObjectName("cff_threshold")
        self.verticalLayout_4.addWidget(self.cff_threshold)
        spacerItem7 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem7)
        self.cff_maxfev = QtWidgets.QLineEdit(self.tab_2)
        self.cff_maxfev.setMinimumSize(QtCore.QSize(0, 35))
        self.cff_maxfev.setObjectName("cff_maxfev")
        self.verticalLayout_4.addWidget(self.cff_maxfev)
        spacerItem8 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem8)
        self.horizontalLayout_4.addLayout(self.verticalLayout_4)
        self.tabWidget.addTab(self.tab_2, "")
        self.verticalLayout_3.addWidget(self.tabWidget)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.pushButton_2 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_2.setObjectName("pushButton_2")
        self.horizontalLayout_2.addWidget(self.pushButton_2)
        self.pushButton = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout_2.addWidget(self.pushButton)
        self.pushButton_3 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_3.setObjectName("pushButton_3")
        self.horizontalLayout_2.addWidget(self.pushButton_3)
        self.verticalLayout_3.addLayout(self.horizontalLayout_2)
        SettingsWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(SettingsWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 752, 26))
        self.menubar.setObjectName("menubar")
        SettingsWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(SettingsWindow)
        self.statusbar.setObjectName("statusbar")
        SettingsWindow.setStatusBar(self.statusbar)

        self.retranslateUi(SettingsWindow)
        self.tabWidget.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(SettingsWindow)

    def retranslateUi(self, SettingsWindow):
        _translate = QtCore.QCoreApplication.translate
        SettingsWindow.setWindowTitle(_translate("SettingsWindow", "Settings"))
        self.label_6.setText(_translate("SettingsWindow", "Defaults"))
        self.label.setText(_translate("SettingsWindow", "GD"))
        self.label_2.setText(_translate("SettingsWindow", "GDD"))
        self.label_3.setText(_translate("SettingsWindow", "TOD"))
        self.label_4.setText(_translate("SettingsWindow", "FOD"))
        self.label_5.setText(_translate("SettingsWindow", "QOD"))
        self.label_9.setText(_translate("SettingsWindow", "+/-"))
        self.label_10.setText(_translate("SettingsWindow", "+/-"))
        self.label_11.setText(_translate("SettingsWindow", "+/-"))
        self.label_12.setText(_translate("SettingsWindow", "+/-"))
        self.label_13.setText(_translate("SettingsWindow", "+/-"))
        self.label_8.setText(_translate("SettingsWindow", "Note: Units in fs"))
        self.label_7.setText(_translate("SettingsWindow", "Done"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("SettingsWindow", "Calibration"))
        self.label_14.setText(_translate("SettingsWindow", "Extend ratio"))
        self.label_15.setText(_translate("SettingsWindow", "r<sup>2</sup> threshold"))
        self.label_16.setText(_translate("SettingsWindow", "Max tries"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), _translate("SettingsWindow", "CFF Autofit options"))
        self.pushButton_2.setText(_translate("SettingsWindow", "Reset all"))
        self.pushButton.setText(_translate("SettingsWindow", "Close"))
        self.pushButton_3.setText(_translate("SettingsWindow", "Save changes"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    SettingsWindow = QtWidgets.QMainWindow()
    ui = Ui_SettingsWindow()
    ui.setupUi(SettingsWindow)
    SettingsWindow.show()
    sys.exit(app.exec_())



import sys

sys.path.append('..')

import unittest
import numpy as np

from pysprint.core import loading

class TestLoading(unittest.TestCase):

	def setUp(self):
		# self.x, self.y, self.v, self.w = np.loadtxt('method_test_w_arms.txt', 
													# delimiter = ',', unpack = True)
		pass
	def tearDown(self):
		pass

	def test_SPP(self):
		a, b = 0, 0 
		self.assertEqual(a,b)

	def test_loading(self):
		self.x, self.y, self.v, self.w = loading.read_data('load_test_1.txt')
		np.testing.assert_array_equal(self.x, np.array([0,0,11]))
		np.testing.assert_array_equal(self.y, np.array([1,1,10]))
		np.testing.assert_array_equal(self.v, np.array([2,2,10]))
		np.testing.assert_array_equal(self.w, np.array([3,3,10]))
		self.x, self.y, self.v, self.w = loading.read_data('load_test_2.txt')
		np.testing.assert_array_equal(self.x, np.array([1,10]))
		np.testing.assert_array_equal(self.y, np.array([0,11]))
		np.testing.assert_array_equal(self.v, np.array([2,10]))
		np.testing.assert_array_equal(self.w, np.array([4,22]))
		with self.assertRaises(FileNotFoundError):
			self.x, self.y, self.v, self.w = loading.read_data('doesnt_exist.txt')


if __name__ == '__main__':
	unittest.main()
		



# -*- coding: utf-8 -*-

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_GeneratorWindow(object):
    def setupUi(self, GeneratorWindow):
        GeneratorWindow.setObjectName("GeneratorWindow")
        GeneratorWindow.resize(984, 877)
        self.centralwidget = QtWidgets.QWidget(GeneratorWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.plotWidget =PlotWidget(self.centralwidget)
        self.plotWidget.setMinimumSize(QtCore.QSize(800, 380))
        self.plotWidget.setObjectName("plotWidget")
        self.verticalLayout_7.addWidget(self.plotWidget)
        self.groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox.setMinimumSize(QtCore.QSize(962, 380))
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem)
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setObjectName("label")
        self.verticalLayout_3.addWidget(self.label)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem1)
        self.label_2 = QtWidgets.QLabel(self.groupBox)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_3.addWidget(self.label_2)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem2)
        self.label_3 = QtWidgets.QLabel(self.groupBox)
        self.label_3.setObjectName("label_3")
        self.verticalLayout_3.addWidget(self.label_3)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem3)
        self.label_4 = QtWidgets.QLabel(self.groupBox)
        self.label_4.setObjectName("label_4")
        self.verticalLayout_3.addWidget(self.label_4)
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem4)
        self.label_5 = QtWidgets.QLabel(self.groupBox)
        self.label_5.setObjectName("label_5")
        self.verticalLayout_3.addWidget(self.label_5)
        spacerItem5 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem5)
        self.label_6 = QtWidgets.QLabel(self.groupBox)
        self.label_6.setObjectName("label_6")
        self.verticalLayout_3.addWidget(self.label_6)
        spacerItem6 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem6)
        self.horizontalLayout_2.addLayout(self.verticalLayout_3)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        spacerItem7 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem7)
        self.startLine = QtWidgets.QLineEdit(self.groupBox)
        self.startLine.setMinimumSize(QtCore.QSize(240, 30))
        self.startLine.setText("")
        self.startLine.setObjectName("startLine")
        self.verticalLayout_2.addWidget(self.startLine)
        spacerItem8 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem8)
        self.stopLine = QtWidgets.QLineEdit(self.groupBox)
        self.stopLine.setMinimumSize(QtCore.QSize(0, 30))
        self.stopLine.setObjectName("stopLine")
        self.verticalLayout_2.addWidget(self.stopLine)
        spacerItem9 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem9)
        self.centerLine = QtWidgets.QLineEdit(self.groupBox)
        self.centerLine.setMinimumSize(QtCore.QSize(0, 30))
        self.centerLine.setObjectName("centerLine")
        self.verticalLayout_2.addWidget(self.centerLine)
        spacerItem10 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem10)
        self.pulseLine = QtWidgets.QLineEdit(self.groupBox)
        self.pulseLine.setMinimumSize(QtCore.QSize(0, 30))
        self.pulseLine.setObjectName("pulseLine")
        self.verticalLayout_2.addWidget(self.pulseLine)
        spacerItem11 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem11)
        self.resolutionLine = QtWidgets.QLineEdit(self.groupBox)
        self.resolutionLine.setMinimumSize(QtCore.QSize(0, 30))
        self.resolutionLine.setObjectName("resolutionLine")
        self.verticalLayout_2.addWidget(self.resolutionLine)
        spacerItem12 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem12)
        self.delayLine = QtWidgets.QLineEdit(self.groupBox)
        self.delayLine.setMinimumSize(QtCore.QSize(0, 30))
        self.delayLine.setObjectName("delayLine")
        self.verticalLayout_2.addWidget(self.delayLine)
        spacerItem13 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem13)
        self.horizontalLayout_2.addLayout(self.verticalLayout_2)
        self.horizontalLayout_4.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        spacerItem14 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem14)
        self.label_7 = QtWidgets.QLabel(self.groupBox)
        self.label_7.setObjectName("label_7")
        self.verticalLayout_5.addWidget(self.label_7)
        spacerItem15 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem15)
        self.label_8 = QtWidgets.QLabel(self.groupBox)
        self.label_8.setObjectName("label_8")
        self.verticalLayout_5.addWidget(self.label_8)
        spacerItem16 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem16)
        self.label_10 = QtWidgets.QLabel(self.groupBox)
        self.label_10.setObjectName("label_10")
        self.verticalLayout_5.addWidget(self.label_10)
        spacerItem17 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem17)
        self.label_9 = QtWidgets.QLabel(self.groupBox)
        self.label_9.setObjectName("label_9")
        self.verticalLayout_5.addWidget(self.label_9)
        spacerItem18 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem18)
        self.label_11 = QtWidgets.QLabel(self.groupBox)
        self.label_11.setObjectName("label_11")
        self.verticalLayout_5.addWidget(self.label_11)
        spacerItem19 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem19)
        self.horizontalLayout_3.addLayout(self.verticalLayout_5)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        spacerItem20 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem20)
        self.GDLine = QtWidgets.QLineEdit(self.groupBox)
        self.GDLine.setMinimumSize(QtCore.QSize(240, 30))
        self.GDLine.setObjectName("GDLine")
        self.verticalLayout_4.addWidget(self.GDLine)
        spacerItem21 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem21)
        self.GDDLine = QtWidgets.QLineEdit(self.groupBox)
        self.GDDLine.setMinimumSize(QtCore.QSize(0, 30))
        self.GDDLine.setObjectName("GDDLine")
        self.verticalLayout_4.addWidget(self.GDDLine)
        spacerItem22 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem22)
        self.TODLine = QtWidgets.QLineEdit(self.groupBox)
        self.TODLine.setMinimumSize(QtCore.QSize(0, 30))
        self.TODLine.setObjectName("TODLine")
        self.verticalLayout_4.addWidget(self.TODLine)
        spacerItem23 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem23)
        self.FODLine = QtWidgets.QLineEdit(self.groupBox)
        self.FODLine.setMinimumSize(QtCore.QSize(0, 30))
        self.FODLine.setObjectName("FODLine")
        self.verticalLayout_4.addWidget(self.FODLine)
        spacerItem24 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem24)
        self.QODLine = QtWidgets.QLineEdit(self.groupBox)
        self.QODLine.setMinimumSize(QtCore.QSize(0, 30))
        self.QODLine.setObjectName("QODLine")
        self.verticalLayout_4.addWidget(self.QODLine)
        spacerItem25 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem25)
        self.horizontalLayout_3.addLayout(self.verticalLayout_4)
        self.horizontalLayout_4.addLayout(self.horizontalLayout_3)
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        spacerItem26 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem26)
        self.label_12 = QtWidgets.QLabel(self.groupBox)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout.addWidget(self.label_12)
        self.delimiterLine = QtWidgets.QLineEdit(self.groupBox)
        self.delimiterLine.setObjectName("delimiterLine")
        self.horizontalLayout.addWidget(self.delimiterLine)
        self.verticalLayout_6.addLayout(self.horizontalLayout)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        spacerItem27 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem27)
        self.armCheck = QtWidgets.QCheckBox(self.groupBox)
        self.armCheck.setObjectName("armCheck")
        self.horizontalLayout_6.addWidget(self.armCheck)
        spacerItem28 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem28)
        self.verticalLayout_6.addLayout(self.horizontalLayout_6)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        spacerItem29 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem29)
        self.label_13 = QtWidgets.QLabel(self.groupBox)
        self.label_13.setObjectName("label_13")
        self.horizontalLayout_5.addWidget(self.label_13)
        self.comboBox = QtWidgets.QComboBox(self.groupBox)
        self.comboBox.setMinimumSize(QtCore.QSize(100, 0))
        self.comboBox.setObjectName("comboBox")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.horizontalLayout_5.addWidget(self.comboBox)
        spacerItem30 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem30)
        self.verticalLayout_6.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_4.addLayout(self.verticalLayout_6)
        self.verticalLayout_8.addLayout(self.horizontalLayout_4)
        self.verticalLayout_7.addWidget(self.groupBox)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.closeButton = QtWidgets.QPushButton(self.centralwidget)
        self.closeButton.setObjectName("closeButton")
        self.horizontalLayout_7.addWidget(self.closeButton)
        self.pushButton_2 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_2.setObjectName("pushButton_2")
        self.horizontalLayout_7.addWidget(self.pushButton_2)
        self.pushButton_3 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_3.setObjectName("pushButton_3")
        self.horizontalLayout_7.addWidget(self.pushButton_3)
        self.pushButton_4 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_4.setObjectName("pushButton_4")
        self.horizontalLayout_7.addWidget(self.pushButton_4)
        self.verticalLayout_7.addLayout(self.horizontalLayout_7)
        GeneratorWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(GeneratorWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 984, 26))
        self.menubar.setObjectName("menubar")
        GeneratorWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(GeneratorWindow)
        self.statusbar.setObjectName("statusbar")
        GeneratorWindow.setStatusBar(self.statusbar)


        self.retranslateUi(GeneratorWindow)
        QtCore.QMetaObject.connectSlotsByName(GeneratorWindow)

    def retranslateUi(self, GeneratorWindow):
        _translate = QtCore.QCoreApplication.translate
        GeneratorWindow.setWindowTitle(_translate("GeneratorWindow", "Generator"))
        self.groupBox.setTitle(_translate("GeneratorWindow", "Generator"))
        self.label.setText(_translate("GeneratorWindow", "Start"))
        self.label_2.setText(_translate("GeneratorWindow", "Stop "))
        self.label_3.setText(_translate("GeneratorWindow", "Center"))
        self.label_4.setText(_translate("GeneratorWindow", "Pulse Width"))
        self.label_5.setText(_translate("GeneratorWindow", "Resolution"))
        self.label_6.setText(_translate("GeneratorWindow", "Delay"))
        self.startLine.setPlaceholderText(_translate("GeneratorWindow", "PHz or nm"))
        self.stopLine.setPlaceholderText(_translate("GeneratorWindow", "PHz or nm"))
        self.centerLine.setPlaceholderText(_translate("GeneratorWindow", "PHz or nm"))
        self.pulseLine.setPlaceholderText(_translate("GeneratorWindow", "fs"))
        self.resolutionLine.setPlaceholderText(_translate("GeneratorWindow", "nm"))
        self.delayLine.setPlaceholderText(_translate("GeneratorWindow", "fs"))
        self.label_7.setText(_translate("GeneratorWindow", "GD"))
        self.label_8.setText(_translate("GeneratorWindow", "GDD"))
        self.label_10.setText(_translate("GeneratorWindow", "TOD"))
        self.label_9.setText(_translate("GeneratorWindow", "FOD"))
        self.label_11.setText(_translate("GeneratorWindow", "QOD"))
        self.GDLine.setPlaceholderText(_translate("GeneratorWindow", "1/fs"))
        self.GDDLine.setPlaceholderText(_translate("GeneratorWindow", "1/fs^2"))
        self.TODLine.setPlaceholderText(_translate("GeneratorWindow", "1/fs^3"))
        self.FODLine.setPlaceholderText(_translate("GeneratorWindow", "1/fs^4"))
        self.QODLine.setPlaceholderText(_translate("GeneratorWindow", "1/fs^5"))
        self.label_12.setText(_translate("GeneratorWindow", "Delimiter"))
        self.delimiterLine.setPlaceholderText(_translate("GeneratorWindow", ","))
        self.armCheck.setText(_translate("GeneratorWindow", "Include Arms"))
        self.label_13.setText(_translate("GeneratorWindow", "Output in "))
        self.comboBox.setItemText(0, _translate("GeneratorWindow", "frequency"))
        self.comboBox.setItemText(1, _translate("GeneratorWindow", "wavelength"))
        self.closeButton.setText(_translate("GeneratorWindow", "Close"))
        self.pushButton_2.setText(_translate("GeneratorWindow", "Save as"))
        self.pushButton_3.setText(_translate("GeneratorWindow", "_currently_unused_"))
        self.pushButton_4.setText(_translate("GeneratorWindow", "Generate and preview"))

from pysprint.ui.plotwidget import PlotWidget

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    GeneratorWindow = QtWidgets.QMainWindow()
    ui = Ui_GeneratorWindow()
    ui.setupUi(GeneratorWindow)
    GeneratorWindow.show()
    sys.exit(app.exec_())




'''
This file helps to load in data with auto detection features. Bugs might be encountered, currently working on fix.

'''

import numpy as np
import pandas as pd
from difflib import SequenceMatcher
from heapq import nlargest as _nlargest

toLookFor = ['PHz', 'frequency','omega', 'wavelength', 'nm','lambda', 'intensity', 'int', 'ref', 'reference', 'sam', 'sample']

xAxis = toLookFor[:6]
yAxis = toLookFor[6:8]
refAxis = toLookFor[8:10]
samAxis = toLookFor[10:]


def get_matches(word, possibilities, n=3, cutoff=0.7):
    if not n >  0:
        raise ValueError("n must be > 0: %r" % (n,))
    if not 0.0 <= cutoff <= 1.0:
        raise ValueError("cutoff must be in [0.0, 1.0]: %r" % (cutoff,))
    result = []
    s = SequenceMatcher()
    s.set_seq2(word)
    for idx, x in enumerate(possibilities):
        s.set_seq1(x)
        if s.real_quick_ratio() >= cutoff and \
           s.quick_ratio() >= cutoff and \
           s.ratio() >= cutoff:
            result.append((s.ratio(), idx))
    result = _nlargest(n, result)
    return [x for score, x in result]

def has_header(file, nrows=20):
	try:
		df = pd.read_csv(file, header=None, nrows=nrows)
	except:
		pass
	df_header = pd.read_csv(file, nrows=nrows)
	return tuple(df.dtypes) != tuple(df_header.dtypes)


def read_data(file):
	matches = []
	initSpectrumX = np.array([])
	initSpectrumY = np.array([])
	ref = np.array([])
	sam = np.array([])
	try:
		df = pd.read_csv(file)
	except FileNotFoundError:
		raise FileNotFoundError('File does not exist.')
	if len(df.columns) == 2:
		test = False
	else:
		test = True
	# print(has_header(file))
	if has_header(file):
		for string in toLookFor:
			indexes = get_matches(string, df.columns.to_numpy(), n=1, cutoff = 0.66)
			if len(indexes)>0:
				matches.append([indexes,string])
	else:
		if len(df.columns) == 2:
			df = pd.read_csv(file, header = None, names = ['x','y'])
			initSpectrumX = df.x.values
			initSpectrumY = df.y.values
		elif len(df.columns) == 3:
			df = pd.read_csv(file, header = None, names = ['x','y','z'])
			df.drop(df.columns[len(df.columns)-1], axis=1, inplace=True)
		elif len(df.columns) == 4:
			df = pd.read_csv(file, header = None, names = ['x','y', 'refY', 'samY'])
			initSpectrumX = df.x.values
			initSpectrumY = df.y.values
			sam = df.samY.values
			ref = df.refY.values
		else:
			length = len(df.columns) 
			df[df.columns] = df[df.columns].apply(pd.to_numeric, errors='coerce', axis=1)
			to_add = ['{}'.format(_) for _ in range(length-3)]
			names = ['x','y','ref', 'sam']
			names.extend(to_add)
			df = pd.read_csv(file, header = None, names = names)
			df.drop(df.columns[4:], axis = 1, inplace=True)
			df = df.dropna(how = 'any', axis = 0)
			initSpectrumX = df.x.values
			initSpectrumY = df.y.values
			ref = df.ref.values
			sam = df.sam.values


	df[df.columns] = df[df.columns].apply(pd.to_numeric, errors='coerce', axis=1)
	df = df.dropna(how = 'any', axis = 0)
	# print(matches)
	# print(df)
	for item in matches:
		if item[1] in xAxis:
			try:
				initSpectrumX = df.iloc[:,item[0][0]].values
				df.iloc[0,item[0][0]] = 'crowded'
				if df.iloc[0,item[0][0]] == 'crowded':
					df = df.drop(df.columns[item[0][0]], axis=1)
					# print('df')
			except:
				pass
		elif item[1] in yAxis:
			try:
				initSpectrumY = df.iloc[:,item[0][0]].values
				df.iloc[0,item[0][0]] = 'crowded'
				if df.iloc[0,item[0][0]] == 'crowded':
					df = df.drop(df.columns[item[0][0]], axis=1)
					# print('f')
				# print(initSpectrumY[:3])
			except:
				pass
		elif item[1] in refAxis:
			try:
				ref = df.iloc[:,item[0][0]].values
				df.iloc[0,item[0][0]] = 'crowded'
				if df.iloc[0,item[0][0]] == 'crowded':
					df = df.drop(df.columns[item[0][0]], axis=1)
					# print('ddf')
			except:
				pass

		elif item[1] in samAxis:
			try:
				sam = df.iloc[:,item[0][0]].values
				df.iloc[0,item[0][0]] = 'crowded'
				if df.iloc[0,item[0][0]] == 'crowded':
					df = df.drop(df.columns[item[0][0]], axis=1)
					# print('dfdd')
			except:
				pass


	if len(initSpectrumX) == 0:
		try:
			initSpectrumX = df.iloc[:,0].values
			df = df.drop(df.columns[0], axis=1)
		except:
			pass
	if len(initSpectrumY) == 0:
		try:
			initSpectrumY = df.iloc[:,0].values
			df = df.drop(df.columns[0], axis=1)
		except:
			pass
	if len(ref) == 0:
		if test:
			try:
				ref = df.iloc[:,0].values
				df = df.drop(df.columns[0], axis=1)
				
			except:
				pass
		else:
			pass
	if len(sam) == 0:
		if test:
			try:
				sam = df.iloc[:,0].values
				df = df.drop(df.columns[0], axis=1)
			except:
				pass
		else:
			pass

	return initSpectrumX, initSpectrumY, ref, sam


# x,y,reference,sample = read_data('')

# print(x[:3])
# print(y[:3])
# print(reference[:3])
# print(sample[:3])



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui.ui'
#
# Created by: PyQt5 UI code generator 5.13.1
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Interferometry(object):
    def setupUi(self, Interferometry):
        Interferometry.setObjectName("PySprint")
        Interferometry.resize(1800, 921)
        self.centralwidget = QtWidgets.QWidget(Interferometry)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        spacerItem = QtWidgets.QSpacerItem(20, 24, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_8.addItem(spacerItem)
        self.logOutput = QtWidgets.QTextEdit(self.centralwidget)
        self.logOutput.setMinimumSize(QtCore.QSize(320, 0))
        self.logOutput.setBaseSize(QtCore.QSize(369, 214))
        self.logOutput.setReadOnly(True)
        self.logOutput.setObjectName("logOutput")
        self.verticalLayout_8.addWidget(self.logOutput)
        self.calculate = QtWidgets.QPushButton(self.centralwidget)
        self.calculate.setObjectName("calculate")
        self.verticalLayout_8.addWidget(self.calculate)
        self.gridLayout_7.addLayout(self.verticalLayout_8, 2, 2, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.btn_load = QtWidgets.QPushButton(self.centralwidget)
        self.btn_load.setMinimumSize(QtCore.QSize(100, 28))
        self.btn_load.setObjectName("btn_load")
        self.horizontalLayout.addWidget(self.btn_load)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem1)
        self.swapButton = QtWidgets.QPushButton(self.centralwidget)
        self.swapButton.setMinimumSize(QtCore.QSize(100, 28))
        self.swapButton.setObjectName("swapButton")
        self.horizontalLayout.addWidget(self.swapButton)
        self.gridLayout_7.addLayout(self.horizontalLayout, 0, 0, 1, 1)
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.editTab = QtWidgets.QTabWidget(self.centralwidget)
        self.editTab.setBaseSize(QtCore.QSize(369, 465))
        self.editTab.setObjectName("editTab")
        self.savgolTab = QtWidgets.QWidget()
        self.savgolTab.setObjectName("savgolTab")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.savgolTab)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.horizontalLayout_23 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_23.setObjectName("horizontalLayout_23")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout()
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_12.addItem(spacerItem2)
        self.savgolWindow = QtWidgets.QLineEdit(self.savgolTab)
        self.savgolWindow.setMinimumSize(QtCore.QSize(0, 40))
        self.savgolWindow.setObjectName("savgolWindow")
        self.verticalLayout_12.addWidget(self.savgolWindow)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_12.addItem(spacerItem3)
        self.savgolOrder = QtWidgets.QLineEdit(self.savgolTab)
        self.savgolOrder.setMinimumSize(QtCore.QSize(0, 40))
        self.savgolOrder.setObjectName("savgolOrder")
        self.verticalLayout_12.addWidget(self.savgolOrder)
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_12.addItem(spacerItem4)
        self.horizontalLayout_23.addLayout(self.verticalLayout_12)
        self.gridLayout_4.addLayout(self.horizontalLayout_23, 0, 0, 1, 1)
        self.editTab.addTab(self.savgolTab, "")
        self.peakTab = QtWidgets.QWidget()
        self.peakTab.setObjectName("peakTab")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.peakTab)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.horizontalLayout_25 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_25.setObjectName("horizontalLayout_25")
        self.verticalLayout_15 = QtWidgets.QVBoxLayout()
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        spacerItem5 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_15.addItem(spacerItem5)
        self.peaksMin = QtWidgets.QLineEdit(self.peakTab)
        self.peaksMin.setMinimumSize(QtCore.QSize(0, 40))
        self.peaksMin.setObjectName("peaksMin")
        self.verticalLayout_15.addWidget(self.peaksMin)
        spacerItem6 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_15.addItem(spacerItem6)
        self.peaksMax = QtWidgets.QLineEdit(self.peakTab)
        self.peaksMax.setMinimumSize(QtCore.QSize(0, 40))
        self.peaksMax.setObjectName("peaksMax")
        self.verticalLayout_15.addWidget(self.peaksMax)
        spacerItem7 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_15.addItem(spacerItem7)
        self.peaksThreshold = QtWidgets.QLineEdit(self.peakTab)
        self.peaksThreshold.setMinimumSize(QtCore.QSize(0, 40))
        self.peaksThreshold.setObjectName("peaksThreshold")
        self.verticalLayout_15.addWidget(self.peaksThreshold)
        spacerItem8 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_15.addItem(spacerItem8)
        self.horizontalLayout_25.addLayout(self.verticalLayout_15)
        self.gridLayout_3.addLayout(self.horizontalLayout_25, 0, 0, 1, 1)
        self.editTab.addTab(self.peakTab, "")
        self.convolTab = QtWidgets.QWidget()
        self.convolTab.setObjectName("convolTab")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.convolTab)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout()
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.convolutionStd = QtWidgets.QLineEdit(self.convolTab)
        self.convolutionStd.setMinimumSize(QtCore.QSize(0, 40))
        self.convolutionStd.setObjectName("convolutionStd")
        self.verticalLayout_14.addWidget(self.convolutionStd)
        self.gridLayout_2.addLayout(self.verticalLayout_14, 0, 0, 1, 1)
        self.editTab.addTab(self.convolTab, "")
        self.cutTab = QtWidgets.QWidget()
        self.cutTab.setObjectName("cutTab")
        self.gridLayout = QtWidgets.QGridLayout(self.cutTab)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout_24 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_24.setObjectName("horizontalLayout_24")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout()
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        spacerItem9 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_13.addItem(spacerItem9)
        self.sliceStart = QtWidgets.QLineEdit(self.cutTab)
        self.sliceStart.setMinimumSize(QtCore.QSize(0, 40))
        self.sliceStart.setObjectName("sliceStart")
        self.verticalLayout_13.addWidget(self.sliceStart)
        spacerItem10 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_13.addItem(spacerItem10)
        self.sliceStop = QtWidgets.QLineEdit(self.cutTab)
        self.sliceStop.setMinimumSize(QtCore.QSize(0, 40))
        self.sliceStop.setObjectName("sliceStop")
        self.verticalLayout_13.addWidget(self.sliceStop)
        spacerItem11 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_13.addItem(spacerItem11)
        self.horizontalLayout_24.addLayout(self.verticalLayout_13)
        self.gridLayout.addLayout(self.horizontalLayout_24, 0, 0, 1, 1)
        self.editTab.addTab(self.cutTab, "")
        self.verticalLayout_5.addWidget(self.editTab)
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem12)
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.temporalApplyButton = QtWidgets.QPushButton(self.centralwidget)
        self.temporalApplyButton.setMinimumSize(QtCore.QSize(150, 40))
        self.temporalApplyButton.setObjectName("temporalApplyButton")
        self.verticalLayout_7.addWidget(self.temporalApplyButton)
        spacerItem13 = QtWidgets.QSpacerItem(20, 5, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_7.addItem(spacerItem13)
        self.commitChanges = QtWidgets.QPushButton(self.centralwidget)
        self.commitChanges.setMinimumSize(QtCore.QSize(150, 40))
        self.commitChanges.setObjectName("commitChanges")
        self.verticalLayout_7.addWidget(self.commitChanges)
        self.horizontalLayout_7.addLayout(self.verticalLayout_7)
        spacerItem14 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem14)
        self.verticalLayout_5.addLayout(self.horizontalLayout_7)
        self.gridLayout_7.addLayout(self.verticalLayout_5, 0, 2, 2, 1)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.resetButton = QtWidgets.QPushButton(self.centralwidget)
        self.resetButton.setMinimumSize(QtCore.QSize(100, 28))
        self.resetButton.setObjectName("resetButton")
        self.horizontalLayout_4.addWidget(self.resetButton)
        spacerItem15 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem15)
        self.refreshGraph = QtWidgets.QPushButton(self.centralwidget)
        self.refreshGraph.setMinimumSize(QtCore.QSize(100, 28))
        self.refreshGraph.setObjectName("refreshGraph")
        self.horizontalLayout_4.addWidget(self.refreshGraph)
        self.gridLayout_7.addLayout(self.horizontalLayout_4, 0, 1, 1, 1)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.comboBox = QtWidgets.QComboBox(self.centralwidget)
        self.comboBox.setMinimumSize(QtCore.QSize(150, 0))
        self.comboBox.setObjectName("comboBox")
        self.comboBox.addItem("")
        self.comboBox.addItem("")
        self.horizontalLayout_8.addWidget(self.comboBox)
        spacerItem16 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem16)
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setObjectName("label")
        self.horizontalLayout_8.addWidget(self.label)
        spacerItem17 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem17)
        self.verticalLayout.addLayout(self.horizontalLayout_8)
        self.tableWidget = QtWidgets.QTableWidget(self.centralwidget)
        self.tableWidget.setMinimumSize(QtCore.QSize(0, 735))
        self.tableWidget.setMaximumSize(QtCore.QSize(450, 16777215))
        self.tableWidget.setBaseSize(QtCore.QSize(379, 738))
        self.tableWidget.setObjectName("tableWidget")
        self.tableWidget.setColumnCount(0)
        self.tableWidget.setRowCount(0)
        self.verticalLayout.addWidget(self.tableWidget)
        spacerItem18 = QtWidgets.QSpacerItem(20, 1, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem18)
        self.gridLayout_7.addLayout(self.verticalLayout, 1, 0, 2, 1)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.MplWidget = MplWidget(self.centralwidget)
        self.MplWidget.setMinimumSize(QtCore.QSize(400, 400))
        self.MplWidget.setSizePolicy(QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum))
        self.MplWidget.setObjectName("MplWidget")
        self.verticalLayout_2.addWidget(self.MplWidget)
        self.gridLayout_7.addLayout(self.verticalLayout_2, 1, 1, 1, 1)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.methodWidget = QtWidgets.QTabWidget(self.centralwidget)
        self.methodWidget.setMinimumSize(QtCore.QSize(0, 290))
        self.methodWidget.setBaseSize(QtCore.QSize(869, 249))
        self.methodWidget.setAutoFillBackground(False)
        self.methodWidget.setTabsClosable(False)
        self.methodWidget.setMovable(False)
        self.methodWidget.setTabBarAutoHide(False)
        self.methodWidget.setObjectName("methodWidget")
        self.sppTab = QtWidgets.QWidget()
        self.sppTab.setObjectName("sppTab")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.sppTab)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.pushButton = QtWidgets.QPushButton(self.sppTab)
        self.pushButton.setMinimumSize(QtCore.QSize(0, 100))
        self.pushButton.setObjectName("pushButton")
        self.verticalLayout_4.addWidget(self.pushButton)
        self.methodWidget.addTab(self.sppTab, "")
        self.cffTab = QtWidgets.QWidget()
        self.cffTab.setObjectName("cffTab")
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout(self.cffTab)
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout()
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.iReferenceArm = QtWidgets.QPushButton(self.cffTab)
        self.iReferenceArm.setMinimumSize(QtCore.QSize(150, 40))
        self.iReferenceArm.setObjectName("iReferenceArm")
        self.horizontalLayout_13.addWidget(self.iReferenceArm)
        spacerItem19 = QtWidgets.QSpacerItem(380, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_13.addItem(spacerItem19)
        self.cff_init = QtWidgets.QLineEdit(self.cffTab)
        self.cff_init.setMinimumSize(QtCore.QSize(0, 30))
        self.cff_init.setObjectName("cff_init")
        self.horizontalLayout_13.addWidget(self.cff_init)
        spacerItem20 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_13.addItem(spacerItem20)
        self.cff_cent = QtWidgets.QLineEdit(self.cffTab)
        self.cff_cent.setMinimumSize(QtCore.QSize(0, 30))
        self.cff_cent.setText("")
        self.cff_cent.setObjectName("cff_cent")
        self.horizontalLayout_13.addWidget(self.cff_cent)
        spacerItem21 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_13.addItem(spacerItem21)
        self.cff_autofit = QtWidgets.QPushButton(self.cffTab)
        self.cff_autofit.setMinimumSize(QtCore.QSize(0, 40))
        self.cff_autofit.setObjectName("cff_autofit")
        self.horizontalLayout_13.addWidget(self.cff_autofit)
        spacerItem22 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_13.addItem(spacerItem22)
        self.verticalLayout_9.addLayout(self.horizontalLayout_13)
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.iSampleArm = QtWidgets.QPushButton(self.cffTab)
        self.iSampleArm.setMinimumSize(QtCore.QSize(150, 40))
        self.iSampleArm.setObjectName("iSampleArm")
        self.horizontalLayout_14.addWidget(self.iSampleArm)
        spacerItem23 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem23)
        self.label_2 = QtWidgets.QLabel(self.cffTab)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_14.addWidget(self.label_2)
        spacerItem24 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem24)
        self.CFF_ref = QtWidgets.QLineEdit(self.cffTab)
        self.CFF_ref.setMinimumSize(QtCore.QSize(0, 30))
        self.CFF_ref.setObjectName("CFF_ref")
        self.horizontalLayout_14.addWidget(self.CFF_ref)
        spacerItem25 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem25)
        self.CFF_fitnow = QtWidgets.QPushButton(self.cffTab)
        self.CFF_fitnow.setMinimumSize(QtCore.QSize(0, 40))
        self.CFF_fitnow.setObjectName("CFF_fitnow")
        self.horizontalLayout_14.addWidget(self.CFF_fitnow)
        spacerItem26 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem26)
        self.verticalLayout_9.addLayout(self.horizontalLayout_14)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        spacerItem27 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem27)
        self.CFF_c1 = QtWidgets.QLineEdit(self.cffTab)
        self.CFF_c1.setMinimumSize(QtCore.QSize(0, 30))
        self.CFF_c1.setObjectName("CFF_c1")
        self.horizontalLayout_9.addWidget(self.CFF_c1)
        spacerItem28 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem28)
        self.CFF_c2 = QtWidgets.QLineEdit(self.cffTab)
        self.CFF_c2.setMinimumSize(QtCore.QSize(0, 30))
        self.CFF_c2.setObjectName("CFF_c2")
        self.horizontalLayout_9.addWidget(self.CFF_c2)
        spacerItem29 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem29)
        self.CFF_b0 = QtWidgets.QLineEdit(self.cffTab)
        self.CFF_b0.setMinimumSize(QtCore.QSize(0, 30))
        self.CFF_b0.setObjectName("CFF_b0")
        self.horizontalLayout_9.addWidget(self.CFF_b0)
        spacerItem30 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem30)
        self.initGD = QtWidgets.QLineEdit(self.cffTab)
        self.initGD.setMinimumSize(QtCore.QSize(70, 30))
        self.initGD.setObjectName("initGD")
        self.horizontalLayout_9.addWidget(self.initGD)
        spacerItem31 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem31)
        self.initGDD = QtWidgets.QLineEdit(self.cffTab)
        self.initGDD.setMinimumSize(QtCore.QSize(70, 30))
        self.initGDD.setObjectName("initGDD")
        self.horizontalLayout_9.addWidget(self.initGDD)
        spacerItem32 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem32)
        self.initTOD = QtWidgets.QLineEdit(self.cffTab)
        self.initTOD.setMinimumSize(QtCore.QSize(70, 30))
        self.initTOD.setObjectName("initTOD")
        self.horizontalLayout_9.addWidget(self.initTOD)
        spacerItem33 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem33)
        self.initFOD = QtWidgets.QLineEdit(self.cffTab)
        self.initFOD.setMinimumSize(QtCore.QSize(70, 30))
        self.initFOD.setObjectName("initFOD")
        self.horizontalLayout_9.addWidget(self.initFOD)
        spacerItem34 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem34)
        self.initQOD = QtWidgets.QLineEdit(self.cffTab)
        self.initQOD.setMinimumSize(QtCore.QSize(70, 30))
        self.initQOD.setObjectName("initQOD")
        self.horizontalLayout_9.addWidget(self.initQOD)
        spacerItem35 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_9.addItem(spacerItem35)
        self.verticalLayout_9.addLayout(self.horizontalLayout_9)
        self.horizontalLayout_15.addLayout(self.verticalLayout_9)
        self.methodWidget.addTab(self.cffTab, "")
        self.mmTab = QtWidgets.QWidget()
        self.mmTab.setObjectName("mmTab")
        self.verticalLayoutWidget_8 = QtWidgets.QWidget(self.mmTab)
        self.verticalLayoutWidget_8.setGeometry(QtCore.QRect(10, 10, 872, 249))
        self.verticalLayoutWidget_8.setObjectName("verticalLayoutWidget_8")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_8)
        self.verticalLayout_10.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.iReferenceArm_2 = QtWidgets.QPushButton(self.verticalLayoutWidget_8)
        self.iReferenceArm_2.setMinimumSize(QtCore.QSize(150, 40))
        self.iReferenceArm_2.setObjectName("iReferenceArm_2")
        self.horizontalLayout_16.addWidget(self.iReferenceArm_2)
        spacerItem36 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_16.addItem(spacerItem36)
        self.verticalLayout_10.addLayout(self.horizontalLayout_16)
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.iSampleArm_2 = QtWidgets.QPushButton(self.verticalLayoutWidget_8)
        self.iSampleArm_2.setMinimumSize(QtCore.QSize(150, 40))
        self.iSampleArm_2.setObjectName("iSampleArm_2")
        self.horizontalLayout_17.addWidget(self.iSampleArm_2)
        spacerItem37 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem37)
        self.verticalLayout_10.addLayout(self.horizontalLayout_17)
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        spacerItem38 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_18.addItem(spacerItem38)
        self.getSPP = QtWidgets.QLineEdit(self.verticalLayoutWidget_8)
        self.getSPP.setMinimumSize(QtCore.QSize(70, 30))
        self.getSPP.setObjectName("getSPP")
        self.horizontalLayout_18.addWidget(self.getSPP)
        spacerItem39 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_18.addItem(spacerItem39)
        self.mmPoly = QtWidgets.QLineEdit(self.verticalLayoutWidget_8)
        self.mmPoly.setMinimumSize(QtCore.QSize(80, 30))
        self.mmPoly.setObjectName("mmPoly")
        self.horizontalLayout_18.addWidget(self.mmPoly)
        spacerItem40 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_18.addItem(spacerItem40)
        self.printCheck = QtWidgets.QCheckBox(self.verticalLayoutWidget_8)
        self.printCheck.setObjectName("printCheck")
        self.horizontalLayout_18.addWidget(self.printCheck)
        spacerItem41 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_18.addItem(spacerItem41)
        self.checkGraph = QtWidgets.QCheckBox(self.verticalLayoutWidget_8)
        self.checkGraph.setObjectName("checkGraph")
        self.horizontalLayout_18.addWidget(self.checkGraph)
        self.verticalLayout_10.addLayout(self.horizontalLayout_18)
        self.methodWidget.addTab(self.mmTab, "")
        self.fftTab = QtWidgets.QWidget()
        self.fftTab.setObjectName("fftTab")
        self.verticalLayoutWidget_9 = QtWidgets.QWidget(self.fftTab)
        self.verticalLayoutWidget_9.setGeometry(QtCore.QRect(10, 10, 872, 249))
        self.verticalLayoutWidget_9.setObjectName("verticalLayoutWidget_9")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget_9)
        self.verticalLayout_11.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.horizontalLayout_19 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_19.setObjectName("horizontalLayout_19")
        spacerItem42 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_19.addItem(spacerItem42)
        self.doFFT = QtWidgets.QPushButton(self.verticalLayoutWidget_9)
        self.doFFT.setMinimumSize(QtCore.QSize(150, 40))
        self.doFFT.setObjectName("doFFT")
        self.horizontalLayout_19.addWidget(self.doFFT)
        spacerItem43 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_19.addItem(spacerItem43)
        self.interpolate_cb = QtWidgets.QCheckBox(self.verticalLayoutWidget_9)
        self.interpolate_cb.setObjectName("interpolate_cb")
        self.horizontalLayout_19.addWidget(self.interpolate_cb)
        spacerItem44 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_19.addItem(spacerItem44)
        self.verticalLayout_11.addLayout(self.horizontalLayout_19)
        self.horizontalLayout_20 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_20.setObjectName("horizontalLayout_20")
        spacerItem45 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_20.addItem(spacerItem45)
        self.doCut = QtWidgets.QPushButton(self.verticalLayoutWidget_9)
        self.doCut.setMinimumSize(QtCore.QSize(150, 40))
        self.doCut.setObjectName("doCut")
        self.horizontalLayout_20.addWidget(self.doCut)
        spacerItem46 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_20.addItem(spacerItem46)
        self.gaussianCut = QtWidgets.QLineEdit(self.verticalLayoutWidget_9)
        self.gaussianCut.setMinimumSize(QtCore.QSize(140, 30))
        self.gaussianCut.setText("")
        self.gaussianCut.setObjectName("gaussianCut")
        self.horizontalLayout_20.addWidget(self.gaussianCut)
        spacerItem47 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_20.addItem(spacerItem47)
        self.gaussianCut2 = QtWidgets.QLineEdit(self.verticalLayoutWidget_9)
        self.gaussianCut2.setMinimumSize(QtCore.QSize(140, 30))
        self.gaussianCut2.setObjectName("gaussianCut2")
        self.horizontalLayout_20.addWidget(self.gaussianCut2)
        spacerItem48 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_20.addItem(spacerItem48)
        self.window_order = QtWidgets.QLineEdit(self.verticalLayoutWidget_9)
        self.window_order.setMinimumSize(QtCore.QSize(140, 30))
        self.window_order.setObjectName("window_order")
        self.horizontalLayout_20.addWidget(self.window_order)
        spacerItem49 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_20.addItem(spacerItem49)
        self.verticalLayout_11.addLayout(self.horizontalLayout_20)
        self.horizontalLayout_21 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_21.setObjectName("horizontalLayout_21")
        spacerItem50 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_21.addItem(spacerItem50)
        self.doIFFT = QtWidgets.QPushButton(self.verticalLayoutWidget_9)
        self.doIFFT.setMinimumSize(QtCore.QSize(150, 40))
        self.doIFFT.setObjectName("doIFFT")
        self.horizontalLayout_21.addWidget(self.doIFFT)
        spacerItem51 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_21.addItem(spacerItem51)
        self.fft_fitOrder = QtWidgets.QLineEdit(self.verticalLayoutWidget_9)
        self.fft_fitOrder.setMinimumSize(QtCore.QSize(0, 30))
        self.fft_fitOrder.setObjectName("fft_fitOrder")
        self.horizontalLayout_21.addWidget(self.fft_fitOrder)
        spacerItem52 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_21.addItem(spacerItem52)
        self.fft_ref = QtWidgets.QLineEdit(self.verticalLayoutWidget_9)
        self.fft_ref.setMinimumSize(QtCore.QSize(0, 30))
        self.fft_ref.setObjectName("fft_ref")
        self.horizontalLayout_21.addWidget(self.fft_ref)
        spacerItem53 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_21.addItem(spacerItem53)
        self.fft_cb = QtWidgets.QCheckBox(self.verticalLayoutWidget_9)
        self.fft_cb.setObjectName("fft_cb")
        self.horizontalLayout_21.addWidget(self.fft_cb)
        self.verticalLayout_11.addLayout(self.horizontalLayout_21)
        self.methodWidget.addTab(self.fftTab, "")
        self.verticalLayout_3.addWidget(self.methodWidget)
        self.gridLayout_7.addLayout(self.verticalLayout_3, 2, 1, 1, 1)
        Interferometry.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(Interferometry)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1800, 26))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuEdit = QtWidgets.QMenu(self.menubar)
        self.menuEdit.setObjectName("menuEdit")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        self.menuPreferences = QtWidgets.QMenu(self.menubar)
        self.menuPreferences.setObjectName("menuPreferences")
        Interferometry.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(Interferometry)
        self.statusbar.setObjectName("statusbar")
        Interferometry.setStatusBar(self.statusbar)
        self.actionSave_log_file = QtWidgets.QAction(Interferometry)
        self.actionSave_log_file.setObjectName("actionSave_log_file")
        self.actionSave_current_data = QtWidgets.QAction(Interferometry)
        self.actionSave_current_data.setObjectName("actionSave_current_data")
        self.actionLoad_data_manually = QtWidgets.QAction(Interferometry)
        self.actionLoad_data_manually.setObjectName("actionLoad_data_manually")
        self.actionExit = QtWidgets.QAction(Interferometry)
        self.actionExit.setObjectName("actionExit")
        self.actionAbout = QtWidgets.QAction(Interferometry)
        self.actionAbout.setObjectName("actionAbout")
        self.action = QtWidgets.QAction(Interferometry)
        self.action.setObjectName("action")
        self.actionRedo = QtWidgets.QAction(Interferometry)
        self.actionRedo.setObjectName("actionRedo")
        self.actionGenerator = QtWidgets.QAction(Interferometry)
        self.actionGenerator.setObjectName("actionGenerator")
        self.actionUnit_converter = QtWidgets.QAction(Interferometry)
        self.actionUnit_converter.setObjectName("actionUnit_converter")
        self.actionOpen_documentation = QtWidgets.QAction(Interferometry)
        self.actionOpen_documentation.setObjectName("actionOpen_documentation")
        self.actionSettings = QtWidgets.QAction(Interferometry)
        self.actionSettings.setObjectName("actionSettings")
        self.menuFile.addAction(self.actionSave_log_file)
        self.menuFile.addAction(self.actionSave_current_data)
        self.menuFile.addAction(self.actionLoad_data_manually)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionExit)
        self.menuEdit.addAction(self.actionSettings)
        self.menuHelp.addAction(self.actionAbout)
        self.menuHelp.addAction(self.actionOpen_documentation)
        self.menuPreferences.addAction(self.actionGenerator)
        self.menuPreferences.addAction(self.actionUnit_converter)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menuPreferences.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(Interferometry)
        self.editTab.setCurrentIndex(0)
        self.methodWidget.setCurrentIndex(3)
        QtCore.QMetaObject.connectSlotsByName(Interferometry)

    def retranslateUi(self, Interferometry):
        _translate = QtCore.QCoreApplication.translate
        Interferometry.setWindowTitle(_translate("Interferometry", "PySprint"))
        self.calculate.setText(_translate("Interferometry", "Calculate"))
        self.btn_load.setText(_translate("Interferometry", "Load data"))
        self.swapButton.setText(_translate("Interferometry", "Swap axes"))
        self.savgolWindow.setPlaceholderText(_translate("Interferometry", "Window size"))
        self.savgolOrder.setPlaceholderText(_translate("Interferometry", "Order"))
        self.editTab.setTabText(self.editTab.indexOf(self.savgolTab), _translate("Interferometry", "Savitzky-Golay filter"))
        self.peaksMin.setPlaceholderText(_translate("Interferometry", "Min. prominence"))
        self.peaksMax.setPlaceholderText(_translate("Interferometry", "Max. prominence"))
        self.peaksThreshold.setPlaceholderText(_translate("Interferometry", "Threshold"))
        self.editTab.setTabText(self.editTab.indexOf(self.peakTab), _translate("Interferometry", "Peaks"))
        self.convolutionStd.setPlaceholderText(_translate("Interferometry", "Standard deviation"))
        self.editTab.setTabText(self.editTab.indexOf(self.convolTab), _translate("Interferometry", "Convolution"))
        self.sliceStart.setPlaceholderText(_translate("Interferometry", "Start value"))
        self.sliceStop.setPlaceholderText(_translate("Interferometry", "End value"))
        self.editTab.setTabText(self.editTab.indexOf(self.cutTab), _translate("Interferometry", "Cut"))
        self.temporalApplyButton.setText(_translate("Interferometry", "Preview"))
        self.commitChanges.setText(_translate("Interferometry", "Commit"))
        self.resetButton.setText(_translate("Interferometry", "Clear data"))
        self.refreshGraph.setText(_translate("Interferometry", "Refresh graph"))
        self.comboBox.setItemText(0, _translate("Interferometry", "PHz"))
        self.comboBox.setItemText(1, _translate("Interferometry", "nm"))
        self.label.setText(_translate("Interferometry", "Data preview"))
        self.pushButton.setText(_translate("Interferometry", "Open Interface"))
        self.methodWidget.setTabText(self.methodWidget.indexOf(self.sppTab), _translate("Interferometry", "SPP"))
        self.iReferenceArm.setText(_translate("Interferometry", "Reference Arm"))
        self.cff_init.setPlaceholderText(_translate("Interferometry", "Initial region ratio"))
        self.cff_cent.setPlaceholderText(_translate("Interferometry", "Center"))
        self.cff_autofit.setText(_translate("Interferometry", "Auto fit"))
        self.iSampleArm.setText(_translate("Interferometry", "Sample Arm"))
        self.label_2.setText(_translate("Interferometry", "y = c1 + c2·cos(b0 + GD· Δω + GDD/2 · Δω^2 + TOD/6 · Δω^3 + FOD/24· Δω^4 + QOD/120· Δω^5 ) "))
        self.CFF_ref.setPlaceholderText(_translate("Interferometry", "Reference point"))
        self.CFF_fitnow.setText(_translate("Interferometry", "Manual fit"))
        self.CFF_c1.setPlaceholderText(_translate("Interferometry", "c1"))
        self.CFF_c2.setPlaceholderText(_translate("Interferometry", "c2"))
        self.CFF_b0.setPlaceholderText(_translate("Interferometry", "b0"))
        self.initGD.setPlaceholderText(_translate("Interferometry", "GD"))
        self.initGDD.setPlaceholderText(_translate("Interferometry", "GDD"))
        self.initTOD.setPlaceholderText(_translate("Interferometry", "TOD"))
        self.initFOD.setPlaceholderText(_translate("Interferometry", "FOD"))
        self.initQOD.setPlaceholderText(_translate("Interferometry", "QOD"))
        self.methodWidget.setTabText(self.methodWidget.indexOf(self.cffTab), _translate("Interferometry", "CFF"))
        self.iReferenceArm_2.setText(_translate("Interferometry", "Reference Arm"))
        self.iSampleArm_2.setText(_translate("Interferometry", "Sample Arm"))
        self.getSPP.setPlaceholderText(_translate("Interferometry", "Type reference point position there"))
        self.mmPoly.setPlaceholderText(_translate("Interferometry", "Poly order"))
        self.printCheck.setText(_translate("Interferometry", "Print fit report"))
        self.checkGraph.setText(_translate("Interferometry", "Show Graph"))
        self.methodWidget.setTabText(self.methodWidget.indexOf(self.mmTab), _translate("Interferometry", "MM"))
        self.doFFT.setText(_translate("Interferometry", "1.  IFFT"))
        self.interpolate_cb.setText(_translate("Interferometry", "Interpolate"))
        self.doCut.setText(_translate("Interferometry", "2.  Window"))
        self.gaussianCut.setPlaceholderText(_translate("Interferometry", "Spike"))
        self.gaussianCut2.setPlaceholderText(_translate("Interferometry", "FWHM"))
        self.window_order.setPlaceholderText(_translate("Interferometry", "Gaussian window order"))
        self.doIFFT.setText(_translate("Interferometry", "3.  FFT"))
        self.fft_fitOrder.setPlaceholderText(_translate("Interferometry", "Fit Order"))
        self.fft_ref.setPlaceholderText(_translate("Interferometry", "Reference point"))
        self.fft_cb.setText(_translate("Interferometry", "Show Graph"))
        self.methodWidget.setTabText(self.methodWidget.indexOf(self.fftTab), _translate("Interferometry", "FFT"))
        self.menuFile.setTitle(_translate("Interferometry", "File"))
        self.menuEdit.setTitle(_translate("Interferometry", "Edit"))
        self.menuHelp.setTitle(_translate("Interferometry", "Help"))
        self.menuPreferences.setTitle(_translate("Interferometry", "Tools"))
        self.actionSave_log_file.setText(_translate("Interferometry", "Save log file"))
        self.actionSave_current_data.setText(_translate("Interferometry", "Save current data"))
        self.actionLoad_data_manually.setText(_translate("Interferometry", "Load data manually"))
        self.actionExit.setText(_translate("Interferometry", "Exit"))
        self.actionAbout.setText(_translate("Interferometry", "About"))
        self.action.setText(_translate("Interferometry", "Undo"))
        self.actionRedo.setText(_translate("Interferometry", "Redo"))
        self.actionGenerator.setText(_translate("Interferometry", "Generator"))
        self.actionUnit_converter.setText(_translate("Interferometry", "Import data"))
        self.actionOpen_documentation.setText(_translate("Interferometry", "Open documentation"))
        self.actionSettings.setText(_translate("Interferometry", "Settings"))
from pysprint.ui.mplwidget import MplWidget


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Interferometry = QtWidgets.QMainWindow()
    ui = Ui_Interferometry()
    ui.setupUi(Interferometry)
    Interferometry.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-
import sys
from math import factorial
import operator

import numpy as np
import matplotlib.pyplot as plt
import scipy
from scipy.optimize import curve_fit
from scipy.signal import argrelextrema

try:
	from lmfit import Model
	_has_lmfit = True
except ImportError:
	_has_lmfit = False

sys.path.append('..')

from pysprint.core.edit_features import interpolate_data
from pysprint.utils import findNearest, _handle_input, lmfit_disp, scipy_disp


__all__ = ['min_max_method', 'cos_fit1', 'cos_fit2', 'cos_fit3',
		   'cos_fit4', 'cos_fit5', 'spp_method', 'cff_method', 'fft_method', 'cut_gaussian',
		   'ifft_method', 'args_comp']


def min_max_method(initSpectrumX, initSpectrumY, referenceArmY, sampleArmY, ref_point, maxx=None, minx=None, fitOrder=5, showGraph=False):
	"""
	Calculates the dispersion with minimum-maximum method 

	Parameters
	----------

	initSpectrumX: array-like
	x-axis data

	initSpectrumY: array-like
	y-axis data

	referenceArmY, sampleArmY: array-like
	reference and sample arm spectra evaluated at initSpectrumX

	ref_point: float
	the reference point to calculate order
	
	maxx and minx: array-like
	the accepted minimal and maximal x values (if you want to manually pass)

	fitOrder: int
	degree of polynomial to fit data [1, 5]

	showGraph: bool
	if True returns a matplotlib plot and pauses execution until closing the window

	Returns
	-------

	dispersion: array-like
	[GD, GDD, TOD, FOD, QOD]

	dispersion_std: array-like
	[GD_std, GDD_std, TOD_std, FOD_std, QOD_std]

	fit_report: lmfit report object
	
	"""
	Xdata, Ydata  = _handle_input(initSpectrumX, initSpectrumY, referenceArmY, sampleArmY)
	if maxx is None:
		maxInd = argrelextrema(Ydata, np.greater)
		maxx = Xdata[maxInd]
	if minx is None:
		minInd = argrelextrema(Ydata, np.less)
		minx = Xdata[minInd]

	_, ref_index = findNearest(Xdata,ref_point)

	relNegMaxFreqs = np.array([a for a in (Xdata[ref_index]-maxx) if a<0])
	relNegMinFreqs= np.array([b for b in (Xdata[ref_index]-minx) if b<0])
	relNegFreqs = sorted(np.append(relNegMaxFreqs, relNegMinFreqs))
	relNegFreqs = relNegFreqs[::-1]
	relPosMaxFreqs = np.array([c for c in (Xdata[ref_index]-maxx) if c>0])
	relPosMinFreqs= np.array([d for d in (Xdata[ref_index]-minx) if d>0])
	relPosFreqs = sorted(np.append(relPosMinFreqs,relPosMaxFreqs))

	negValues = np.zeros_like(relNegFreqs)
	posValues = np.zeros_like(relPosFreqs)
	for freq in range(len(relPosFreqs)):
		posValues[freq] = np.pi*(freq+1)
	for freq in range(len(relNegFreqs)):
		negValues[freq] = np.pi*(freq+1)
	x_s = np.append(relPosFreqs, relNegFreqs) 
	y_s = np.append(posValues, negValues)
	#making sure the data in right order
	#FIXME: Do we even need this?
	L = sorted(zip(x_s,y_s), key=operator.itemgetter(0))
	fullXValues, fullYValues = zip(*L)
	
	if _has_lmfit:
		if fitOrder == 5:
			fitModel = Model(polynomialFit5)
			params = fitModel.make_params(b0 = 0, b1 = 1, b2 = 1, b3 = 1, b4 = 1, b5 = 1)
			result = fitModel.fit(fullYValues, x=fullXValues, params = params, method ='leastsq') #nelder
		elif fitOrder == 4:
			fitModel = Model(polynomialFit4)
			params = fitModel.make_params(b0 = 0, b1 = 1, b2 = 1, b3 = 1, b4 = 1)
			result = fitModel.fit(fullYValues, x=fullXValues, params = params, method ='leastsq') 
		elif fitOrder == 3:
			fitModel = Model(polynomialFit3)
			params = fitModel.make_params(b0 = 0, b1 = 1, b2 = 1, b3 = 1)
			result = fitModel.fit(fullYValues, x=fullXValues, params = params, method ='leastsq') 
		elif fitOrder == 2:
			fitModel = Model(polynomialFit2)
			params = fitModel.make_params(b0 = 0, b1 = 1, b2 = 1)
			result = fitModel.fit(fullYValues, x=fullXValues, params = params, method ='leastsq') 
		elif fitOrder == 1:
			fitModel = Model(polynomialFit1)
			params = fitModel.make_params(b0 = 0, b1 = 1)
			result = fitModel.fit(fullYValues, x=fullXValues, params = params, method ='leastsq') 
		else:
			raise ValueError('Order is out of range, please select from [1,5]')
	else:
		if fitOrder == 5:
			popt, pcov = curve_fit(polynomialFit5, fullXValues, fullYValues, maxfev = 8000)
			_function = polynomialFit5
		elif fitOrder == 4:
			popt, pcov = curve_fit(polynomialFit4, fullXValues, fullYValues, maxfev = 8000)
			_function = polynomialFit4
		elif fitOrder == 3:
			popt, pcov = curve_fit(polynomialFit3, fullXValues, fullYValues, maxfev = 8000)
			_function = polynomialFit3
		elif fitOrder == 2:
			popt, pcov = curve_fit(polynomialFit2, fullXValues, fullYValues, maxfev = 8000)
			_function = polynomialFit2
		elif fitOrder == 1:
			popt, pcov = curve_fit(polynomialFit1, fullXValues, fullYValues, maxfev = 8000)
			_function = polynomialFit1
		else:
			raise ValueError('Order is out of range, please select from [1,5]')
	try:
		if _has_lmfit:
			dispersion, dispersion_std = lmfit_disp(result.params.items())
			dispersion = dispersion[1:]
			dispersion_std = dispersion_std[1:]
			for idx in range(len(dispersion)):
				dispersion[idx] =  dispersion[idx] * factorial(idx+1) 
				dispersion_std[idx] =  dispersion_std[idx] * factorial(idx+1)
			while len(dispersion)<5:
				dispersion.append(0)
				dispersion_std.append(0) 
			fit_report = result.fit_report()
		else:
			fullXValues = np.asarray(fullXValues)
			dispersion=[]
			dispersion_std=[]
			for idx in range(len(popt)-1):
				dispersion.append(popt[idx+1]*factorial(idx+1))
			while len(dispersion)<5:
				dispersion.append(0)
			while len(dispersion_std)<len(dispersion):
				dispersion_std.append(0)
			fit_report = '\nTo display detailed results, you must have lmfit installed.'
		if showGraph:
			fig = plt.figure(figsize=(7,7))
			fig.canvas.set_window_title('Min-max method fitted')
			plt.plot(fullXValues, fullYValues, 'o', label = 'dataset')
			try:
				plt.plot(fullXValues, result.best_fit, 'r*', label = 'fitted')
			except Exception:
				plt.plot(fullXValues, _function(fullXValues, *popt), 'r*', label = 'fitted')
			plt.legend()
			plt.grid()
			plt.show()
		return dispersion, dispersion_std, fit_report
	except Exception as e:
		return [0,0,0,0,0],[0,0,0,0,0],e	






def polynomialFit5(x, b0, b1, b2, b3, b4, b5):
	"""
	Taylor polynomial for fit
	b1 = GD
	b2 = GDD / 2
	b3 = TOD / 6
	b4 = FOD / 24
	b5 = QOD / 120
	"""
	return b0+b1*x+b2*x**2+b3*x**3+b4*x**4+b5*x**5

def polynomialFit4(x, b0, b1, b2, b3, b4):
	"""
	Taylor polynomial for fit
	b1 = GD
	b2 = GDD / 2
	b3 = TOD / 6
	b4 = FOD / 24
	"""
	return b0+b1*x+b2*x**2+b3*x**3+b4*x**4

def polynomialFit3(x, b0, b1, b2, b3):
	"""
	Taylor polynomial for fit
	b1 = GD
	b2 = GDD / 2
	b3 = TOD / 6

	"""
	return b0+b1*x+b2*x**2+b3*x**3

def polynomialFit2(x, b0, b1, b2):
	"""
	Taylor polynomial for fit
	b1 = GD
	b2 = GDD / 2
	"""
	return b0+b1*x+b2*x**2

def polynomialFit1(x, b0, b1):
	"""
	Taylor polynomial for fit
	b1 = GD
	"""
	return b0+b1*x

def cos_fit1(x,c0, c1, b0, b1):
	return c0 + c1*np.cos(polynomialFit1(x, b0, b1))

def cos_fit2(x,c0, c1, b0, b1, b2):
	return c0 + c1*np.cos(polynomialFit2(x,b0, b1, b2))

def cos_fit3(x,c0, c1, b0, b1, b2, b3):
	return c0 + c1*np.cos(polynomialFit3(x, b0, b1, b2, b3))

def cos_fit4(x,c0, c1, b0, b1, b2, b3, b4):
	return c0 + c1*np.cos(polynomialFit4(x,b0, b1, b2, b3, b4))

def cos_fit5(x,c0, c1, b0, b1, b2, b3, b4, b5):
	return c0 + c1*np.cos(polynomialFit5(x,b0, b1, b2, b3, b4, b5))


def spp_method(delays, omegas, fitOrder=4, from_raw=False): 
	"""
	Calculates the dispersion from SPP's positions and delays.
	
	Parameters
	----------

	delays: array-like
	the time delays in fs
	if from_raw is enabled you must pass matching pairs with omegas

	omegas: array-like
	in form of [[SPP1, SPP2, SPP3, SPP4],[SPP1, SPP2, SPP3, SPP4], ..]
	for lesser SPP cases replace elements with None:
	[[SPP1, None, None, None],[SPP1, None, None, None], ..]
	if from_raw is enabled, you must pass matching pairs with delays

	fitOrder: int
	order of polynomial to fit the given data

	from_raw: bool
	if True you can pass matching pairs to delays and omegas, and it will perform 
	a normal curve fitting. It's useful at the API.

	Returns
	-------
	omegas_unpacked: array-like
	x axis data

	delays_unpacked : array-like
	y axis data

	dispersion: array-like
	[GD, GDD, TOD, FOD, QOD]

	dispersion_std: array-like
	[GD_std, GDD_std, TOD_std, FOD_std, QOD_std]

	bf: array-like
	best fitting curve for plotting
	"""
	if from_raw:
		delays_unpacked = delays
		omegas_unpacked = omegas
	else:
		delays = delays[delays != np.array(None)]
		omegas_unpacked = []
		delays_unpacked = []
		for delay, element in zip(delays, omegas):
			item = [x for x in element if x is not None]
			omegas_unpacked.extend(item)
			delays_unpacked.extend(len(item) * [delay])
	try:
		if _has_lmfit:
			if fitOrder == 2:
				fitModel = Model(polynomialFit2)
				params = fitModel.make_params(b0 = 1, b1 = 1, b2 = 1)
				result = fitModel.fit(delays_unpacked, x=omegas_unpacked, params = params, method ='leastsq') #nelder
			elif fitOrder == 3:
				fitModel = Model(polynomialFit3)
				params = fitModel.make_params(b0 = 1, b1 = 1, b2 = 1, b3 = 3)
				result = fitModel.fit(delays_unpacked, x=omegas_unpacked, params = params, method ='leastsq') #nelder
			elif fitOrder == 4:
				fitModel = Model(polynomialFit4)
				params = fitModel.make_params(b0 = 1, b1 = 1, b2 = 1, b3=1, b4 =1)
				result = fitModel.fit(delays_unpacked, x=omegas_unpacked, params = params, method ='leastsq') #nelder
			elif fitOrder == 1:
				fitModel = Model(polynomialFit1)
				params = fitModel.make_params(b0 = 1, b1 = 1)
				result = fitModel.fit(delays_unpacked, x=omegas_unpacked, params = params, method ='leastsq') #nelder
			else:
				raise ValueError('Order is out of range, please select from [1,4]')
			dispersion, dispersion_std = lmfit_disp(result.params.items())
			for idx in range(len(dispersion)):
				dispersion[idx] =  dispersion[idx]*factorial(idx) #biztos?
			for idx in range(len(dispersion_std)):
				if dispersion_std[idx] != None:
					dispersion_std[idx] =  dispersion_std[idx] * factorial(idx)
				else:
					dispersion_std[idx] = 0
			while len(dispersion)<5:
				dispersion.append(0)
				dispersion_std.append(0)
			while len(dispersion_std)<5:
				dispersion_std.append(0) 
			bf = result.best_fit
		else:
			if fitOrder == 4:
				popt, pcov = curve_fit(polynomialFit4, omegas_unpacked, delays_unpacked, maxfev = 8000)
				_function = polynomialFit4
			elif fitOrder == 3:
				popt, pcov = curve_fit(polynomialFit3, omegas_unpacked, delays_unpacked, maxfev = 8000)
				_function = polynomialFit3
			elif fitOrder == 2:
				popt, pcov = curve_fit(polynomialFit2, omegas_unpacked, delays_unpacked, maxfev = 8000)
				_function = polynomialFit2
			elif fitOrder == 1:
				popt, pcov = curve_fit(polynomialFit1, omegas_unpacked, delays_unpacked, maxfev = 8000)
				_function = polynomialFit1
			else:
				raise ValueError('Order is out of range, please select from [1,4]')
			#FIXME: biztos?
			omegas_unpacked = np.asarray(omegas_unpacked)
			dispersion=[]
			dispersion_std=[]
			for idx in range(len(popt)):
				dispersion.append(popt[idx]*factorial(idx))
			while len(dispersion)<5:
				dispersion.append(0)
			while len(dispersion_std)<len(dispersion):
				dispersion_std.append(0)
			bf = _function(omegas_unpacked, *popt)
		return omegas_unpacked, delays_unpacked, dispersion, dispersion_std, bf
	except Exception as e:
		return [], [], [e], [], []


def cff_method(initSpectrumX, initSpectrumY, referenceArmY, sampleArmY, ref_point=0 , p0=[1, 1, 1, 1, 1, 1, 1, 1]):
	"""
	Phase modulated cosine function fit method. 
	

	Parameters
	----------
	
	initSpectrumX: array-like
	x-axis data

	initSpectrumY: array-like
	y-axis data

	referenceArmY, sampleArmY: array-like
	the reference and sample arm spectra evaluated at initSpectrumX

	p0: array-like
	the initial parameters for fitting

	Returns
	-------

	dispersion: array-like
	[GD, GDD, TOD, FOD, QOD]

	bf: array-like
	best fitting curve

	"""
	# TODO: BOUNDS WILL BE SET  ..
	# bounds=((-1000, -10000, -10000, -np.inf, -np.inf, -np.inf, -np.inf, -np.inf), 
		    # (1000, 10000, 10000, np.inf, np.inf, np.inf, np.inf, np.inf))
	Xdata, Ydata = _handle_input(initSpectrumX, initSpectrumY, referenceArmY, sampleArmY)
	#TODO: replace with lmfit
	try:
		if len(np.trim_zeros(p0, 'b')) + 4 == len(p0):
			_funct = cos_fit1
			p0 = p0[:-4]
		elif p0[-1] == 0 and p0[-2] == 0 and p0[-3] == 0:
			_funct = cos_fit2
			p0 = p0[:-3]
		elif p0[-1] == 0 and p0[-2] == 0:
			_funct = cos_fit3
			p0 = p0[:-2]
		elif p0[-1] == 0:
			_funct = cos_fit4
			p0 = p0[:-1]
		else:
			_funct = cos_fit5
		popt, pcov = curve_fit(_funct, Xdata-ref_point, Ydata, p0, maxfev = 8000)
		dispersion = np.zeros_like(popt)[:-3]
		for num in range(len(popt)-3):
			dispersion[num] = popt[num+3]/factorial(num)
		# fig1 = plt.figure()
		# fig1.canvas.set_window_title('Cosine function fit method')
		# plt.plot(Xdata, Ydata,'r-',label = 'dataset')
		# plt.plot(Xdata, cosFitForPMCFF(Xdata, *popt),'k*', label = 'fitted')
		# plt.legend()
		# plt.grid()
		# plt.show()
		return dispersion, _funct(Xdata-ref_point, *popt)
	except RuntimeError:
		raise ValueError('Max tries reached.. \n Parameters could not be estimated.')


def fft_method(initSpectrumY):
	"""
	Perfoms FFT on data

	Parameters
	----------

	initSpectrumY: array-like
	y-axis data
	
	Returns
	-------

	yf: array-like
	the transformed y data

	"""
	if len(initSpectrumY) > 0:
		Ydata = initSpectrumY
		yf = scipy.fftpack.fft(Ydata)
		return yf
	if len(initSpectrumY) == 0:
		pass

def gaussian_window(t, tau, standardDev, order):
	"""
	Parameters
	----------
	t: array-like
	input array to perform window on

	tau: float
	center of gaussian window

	standardDev: float
	standard deviation of gaussian window

	Returns
	-------
	arr : array-like
	6th order gaussian window with params above

	"""
	return np.exp(-(t-tau)**order/(2*standardDev**order))

def cut_gaussian(initSpectrumX, initSpectrumY, spike, sigma, win_order):
	"""
	Applies gaussian window with the given params.

	Parameters
	----------
	initSpectrumX: array-like
	x-axis data

	initSpectrumY: array-like
	y-axis data

	spike: float
	center of gaussian window

	sigma: float
	standard deviation of gaussian window

	Returns
	-------

	Ydata: array-like
	the windowed y values 
	
	"""

	Ydata = initSpectrumY * gaussian_window(initSpectrumX, tau = spike, standardDev = sigma, order = win_order) 
	# Ydata = initSpectrumY * scipy.signal.windows.gaussian(len(initSpectrumY), std=sigma)
	return Ydata



def ifft_method(initSpectrumX, initSpectrumY, interpolate = True):
	"""
	Perfoms IFFT on data

	Parameters
	----------

	initSpectrumX: array-like
	the x-axis data

	initSpectrumY: array-like
	the y-axis data

	interpolate: bool
	if True perform a linear interpolation on dataset before transforms
	
	Returns
	-------
	freq: array-like
	the transformed x data

	yf: array-like
	transformed y data

	"""
	if len(initSpectrumY)>0 and len(initSpectrumX)>0:
		Ydata = initSpectrumY
		Xdata = initSpectrumX
	else:
		raise
	if interpolate:
		Xdata, Ydata = interpolate_data(initSpectrumX, initSpectrumY, [],[])
	yf = scipy.fftpack.ifft(Ydata)
	freq = scipy.fftpack.fftfreq(len(Xdata), d=(Xdata[3]-Xdata[2]))
	return freq, yf 
	



def args_comp(initSpectrumX, initSpectrumY, reference_point = 2.5, fitOrder=5, showGraph=False):
	"""
	Calculates the phase of complex dataset then unwrap by changing deltas between 
	values to 2*pi complement. At the end, fit a polynomial curve to determine
	dispersion coeffs.

	Parameters
	----------

	initSpectrumX: array-like
	the x-axis data

	initSpectrumY: array-like
	the y-axis data

	fitOrder: int
	degree of polynomial to fit data [1, 5]

	showGrap: bool
	if True returns a matplotlib plot and pauses execution until closing the window
	
	Returns
	-------

	dispersion: array-like
	[GD, GDD, TOD, FOD, QOD]

	dispersion_std: array-like
	[GD_std, GDD_std, TOD_std, FOD_std, QOD_std]

	fit_report: lmfit report object

	"""
	Xdata = initSpectrumX-reference_point
	angles = np.angle(initSpectrumY)
	###shifting to [0, 2pi] if necessary
	# angles = (angles + 2 * np.pi) % (2 * np.pi)
	Ydata = np.unwrap(angles, axis = 0)
	if fitOrder == 5:
		fitModel = Model(polynomialFit5)
		params = fitModel.make_params(b0 = 0, b1 = 1, b2 = 1, b3 = 1, b4 = 1, b5 = 1)
		result = fitModel.fit(Ydata, x=Xdata, params = params, method ='leastsq') 
	elif fitOrder == 4:
		fitModel = Model(polynomialFit4)
		params = fitModel.make_params(b0 = 0, b1 = 1, b2 = 1, b3 = 1, b4 = 1)
		result = fitModel.fit(Ydata, x=Xdata, params = params, method ='leastsq') 
	elif fitOrder == 3:
		fitModel = Model(polynomialFit3)
		params = fitModel.make_params(b0 = 0, b1 = 1, b2 = 1, b3 = 1)
		result = fitModel.fit(Ydata, x=Xdata, params = params, method ='leastsq') 
	elif fitOrder == 2:
		fitModel = Model(polynomialFit2)
		params = fitModel.make_params(b0 = 0, b1 = 1, b2 = 1)
		result = fitModel.fit(Ydata, x=Xdata, params = params, method ='leastsq') 
	elif fitOrder == 1:
		fitModel = Model(polynomialFit1)
		params = fitModel.make_params(b0 = 0, b1 = 1)
		result = fitModel.fit(Ydata, x=Xdata, params = params, method ='leastsq') 
	else:
		raise ValueError('Order is out of range, please select from [1,5]')
	try:
		dispersion, dispersion_std = [], []
		dispersion, dispersion_std = lmfit_disp(result.params.items())
		dispersion = dispersion[1:]
		dispersion_std = dispersion_std[1:]
		for idx in range(len(dispersion)):
			dispersion[idx] = dispersion[idx] * factorial(idx+1)
			dispersion_std[idx] = dispersion_std[idx] * factorial(idx+1)
		while len(dispersion)<5:
			dispersion.append(0)
			dispersion_std.append(0) 
		fit_report = result.fit_report()
		if showGraph:
			fig = plt.figure(figsize=(7,7))
			fig.canvas.set_window_title('Phase')
			plt.plot(Xdata, Ydata, 'o', label = 'dataset')
			plt.plot(Xdata, result.best_fit, 'r--', label = 'fitted')
			plt.legend()
			plt.grid()
			plt.show()
		return dispersion, dispersion_std, fit_report
	except Exception as e:
		return [0,0,0,0,0],[0,0,0,0,0],e



""" #Teszt
a, b = np.loadtxt('ff.txt', unpack = True, delimiter = ',')
aa, bb = ifft_method(a, b, interpolate = True)
bbb = cut_gaussian(aa, bb, 740, 100, 6) 
bbbb = fft_method(bbb)
angles = np.angle(bbbb)
angles = (angles + 2 * np.pi) % (2 * np.pi)
c = np.unwrap(angles)
plt.plot(aa, c, 'ro')
plt.show()
"""


# -*- coding: utf-8 -*-

from PyQt5 import QtCore, QtGui, QtWidgets
from PyQt5.QtWidgets import QAbstractItemView, QTreeWidget
import numpy as np

class Ui_SPP(object):

    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1302, 832)

        ##
        self.xData = []
        self.yData = []
        self.ySam = []
        self.yRef = []
        self.xtemporal = []
        self.ytemporal = []
        self.xpoints = [[None]]*30
        self.ypoints = [[None]]*30
        self.delays = np.array([None]*30)
        self.cid = None
        ##
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout.setObjectName("gridLayout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.loadButton = QtWidgets.QPushButton(self.centralwidget)
        self.loadButton.setMinimumSize(QtCore.QSize(150, 30))
        self.loadButton.setObjectName("loadButton")
        self.horizontalLayout_2.addWidget(self.loadButton)
        self.pushButton_7 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_7.setObjectName("pushButton_7")
        self.horizontalLayout_2.addWidget(self.pushButton_7)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.treeWidget = QtWidgets.QTreeWidget(self.centralwidget)
        self.treeWidget.setExpandsOnDoubleClick(False)
        self.treeWidget.setObjectName("treeWidget")
        font = QtGui.QFont()
        font.setBold(False)
        font.setUnderline(True)
        font.setWeight(50)
        font.setStrikeOut(False)
        self.treeWidget.headerItem().setFont(0, font)
        self.verticalLayout.addWidget(self.treeWidget)
        self.gridLayout.addLayout(self.verticalLayout, 0, 0, 3, 1)
        self.widget = PlotWidget(self.centralwidget)
        self.widget.setMinimumSize(QtCore.QSize(500, 450))
        self.widget.setObjectName("widget")
        self.gridLayout.addWidget(self.widget, 0, 1, 1, 3)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.delayLine = QtWidgets.QLineEdit(self.centralwidget)
        self.delayLine.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.delayLine.setMinimumSize(QtCore.QSize(0, 30))
        self.delayLine.setObjectName("delayLine")
        self.horizontalLayout.addWidget(self.delayLine)
        self.pushButton = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton.setMinimumSize(QtCore.QSize(0, 30))
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout.addWidget(self.pushButton)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.SPP1 = QtWidgets.QLineEdit(self.centralwidget)
        self.SPP1.setMinimumSize(QtCore.QSize(0, 30))
        self.SPP1.setText("")
        self.SPP1.setObjectName("SPP1")
        self.SPP1.setStyleSheet("""QLineEdit { color: blue }""")
        self.verticalLayout_2.addWidget(self.SPP1)
        self.SPP2 = QtWidgets.QLineEdit(self.centralwidget)
        self.SPP2.setMinimumSize(QtCore.QSize(0, 30))
        self.SPP2.setObjectName("SPP2")
        self.SPP2.setStyleSheet("""QLineEdit { color: orange }""")
        self.verticalLayout_2.addWidget(self.SPP2)
        self.SPP3 = QtWidgets.QLineEdit(self.centralwidget)
        self.SPP3.setMinimumSize(QtCore.QSize(0, 30))
        self.SPP3.setObjectName("SPP3")
        self.SPP3.setStyleSheet("""QLineEdit { color: green }""")
        self.verticalLayout_2.addWidget(self.SPP3)
        self.SPP4 = QtWidgets.QLineEdit(self.centralwidget)
        self.SPP4.setMinimumSize(QtCore.QSize(0, 20))
        self.SPP4.setObjectName("SPP4")
        self.SPP4.setStyleSheet("""QLineEdit { color: purple }""")
        self.SPP4.setMinimumSize(QtCore.QSize(0, 30))
        self.verticalLayout_2.addWidget(self.SPP4)
        self.pushButton_4 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_4.setObjectName("pushButton_4")
        self.verticalLayout_2.addWidget(self.pushButton_4)
        self.verticalLayout_4.addLayout(self.verticalLayout_2)
        self.gridLayout.addLayout(self.verticalLayout_4, 1, 1, 2, 1)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.pushButton_2 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_2.setObjectName("pushButton_2")
        self.horizontalLayout_4.addWidget(self.pushButton_2)
        self.pushButton_3 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_3.setObjectName("pushButton_3")
        self.horizontalLayout_4.addWidget(self.pushButton_3)
        self.gridLayout.addLayout(self.horizontalLayout_4, 1, 2, 1, 1)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.GDSPP = QtWidgets.QLineEdit(self.centralwidget)
        self.GDSPP.setObjectName("GDSPP")
        self.verticalLayout_3.addWidget(self.GDSPP)
        self.GDDSPP = QtWidgets.QLineEdit(self.centralwidget)
        self.GDDSPP.setObjectName("GDDSPP")
        self.verticalLayout_3.addWidget(self.GDDSPP)
        self.TODSPP = QtWidgets.QLineEdit(self.centralwidget)
        self.TODSPP.setObjectName("TODSPP")
        self.verticalLayout_3.addWidget(self.TODSPP)
        self.FODSPP = QtWidgets.QLineEdit(self.centralwidget)
        self.FODSPP.setObjectName("FODSPP")
        self.verticalLayout_3.addWidget(self.FODSPP)
        self.QODSPP = QtWidgets.QLineEdit(self.centralwidget)
        self.QODSPP.setObjectName("QODSPP")
        self.verticalLayout_3.addWidget(self.QODSPP),
        self.messageBox = QtWidgets.QTextEdit(self.centralwidget)
        self.messageBox.setReadOnly(True)
        self.messageBox.setObjectName("messageBox")

        self.verticalLayout_3.addWidget(self.messageBox)
        self.gridLayout.addLayout(self.verticalLayout_3, 1, 3, 2, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.pushButton_5 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_5.setObjectName("pushButton_5")
        self.horizontalLayout_3.addWidget(self.pushButton_5)
        self.fitOrderLine = QtWidgets.QLineEdit(self.centralwidget)
        self.fitOrderLine.setMinimumSize(QtCore.QSize(0, 30))
        self.fitOrderLine.setObjectName("fitOrderLine")
        self.horizontalLayout_3.addWidget(self.fitOrderLine)
        self.pushButton_6 = QtWidgets.QPushButton(self.centralwidget)
        self.pushButton_6.setMinimumSize(QtCore.QSize(0, 30))
        self.pushButton_6.setObjectName("pushButton_6")
        self.horizontalLayout_3.addWidget(self.pushButton_6)
        self.gridLayout.addLayout(self.horizontalLayout_3, 2, 2, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1302, 26))
        self.menubar.setObjectName("menubar")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "SPP Method"))
        self.loadButton.setText(_translate("MainWindow", "Load file"))
        self.pushButton_7.setText(_translate("MainWindow", "Delete item"))
        self.treeWidget.headerItem().setText(0, _translate("MainWindow", "Loaded files"))
        __sortingEnabled = self.treeWidget.isSortingEnabled()
        self.treeWidget.setSortingEnabled(False)
        self.treeWidget.setSortingEnabled(__sortingEnabled)
        self.delayLine.setPlaceholderText(_translate("MainWindow", "delay (fs)"))
        self.pushButton.setText(_translate("MainWindow", "Set delay"))
        self.SPP1.setPlaceholderText(_translate("MainWindow", "SPP1"))
        self.SPP2.setPlaceholderText(_translate("MainWindow", "SPP2"))
        self.SPP3.setPlaceholderText(_translate("MainWindow", "SPP3"))
        self.SPP4.setPlaceholderText(_translate("MainWindow", "SPP4"))
        self.pushButton_4.setText(_translate("MainWindow", "Set SPP"))
        self.pushButton_2.setText(_translate("MainWindow", "Clickable SPP"))
        self.pushButton_3.setText(_translate("MainWindow", "Stop and record"))
        self.GDSPP.setPlaceholderText(_translate("MainWindow", "GD "))
        self.GDDSPP.setPlaceholderText(_translate("MainWindow", "GDD"))
        self.TODSPP.setPlaceholderText(_translate("MainWindow", "TOD"))
        self.FODSPP.setPlaceholderText(_translate("MainWindow", "FOD"))
        self.QODSPP.setPlaceholderText(_translate("MainWindow", "QOD"))
        self.pushButton_5.setText(_translate("MainWindow", "Reset all"))
        self.fitOrderLine.setPlaceholderText(_translate("MainWindow", "Fit order "))
        self.pushButton_6.setText(_translate("MainWindow", "Fit and report"))

from pysprint.ui.plotwidget import PlotWidget

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_SPP()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())

